@@ -96,7 +96,7 @@ from rockset.model.kafka_v3_security_config import KafkaV3SecurityConfig
 from rockset.model.kinesis_collection_creation_request import KinesisCollectionCreationRequest
 from rockset.model.kinesis_integration import KinesisIntegration
 from rockset.model.kinesis_integration_creation_request import KinesisIntegrationCreationRequest
-from rockset.model.kinesis_storage_source_wrapper import KinesisStorageSourceWrapper
+from rockset.model.kinesis_source_wrapper import KinesisSourceWrapper
 from rockset.model.list_aliases_response import ListAliasesResponse
 from rockset.model.list_api_keys_response import ListApiKeysResponse
 from rockset.model.list_collections_response import ListCollectionsResponse
